@@ -1,7 +1,17 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-# SPDX-License-Identifier: Apache-2.0
 """SDC Element module."""
+#   Copyright 2022 Orange, Deutsche Telekom AG
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 from abc import ABC, abstractmethod
 from operator import itemgetter
 from typing import Any, Dict, List, Optional
@@ -165,6 +175,16 @@ class SdcElement(SdcOnboardable, ABC):
         """
         return "{}/{}".format(cls._base_url(), cls._sdc_path())
 
+    @property
+    def delete_url(self) -> str:
+        """Get an url to delete element.
+
+        Returns:
+            str: Url which can be used to delete SDC element
+
+        """
+        return f"{self._get_all_url}/{self.identifier}"
+
     def _copy_object(self, obj: 'SdcElement') -> None:
         """
         Copy relevant properties from object.
@@ -215,3 +235,15 @@ class SdcElement(SdcOnboardable, ABC):
 
         """
         raise NotImplementedError("SdcElement is an abstract class")
+
+    def delete(self) -> None:
+        """Delete SDC element.
+
+        Send a request to SDC to delete that element.
+
+        """
+        self.send_message(
+            "DELETE",
+            "Delete SDC element",
+            self.delete_url
+        )
